/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.0.2, packaged on February2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/

#include "FileEntry.h"
#include <glc_mesh2.h>

// Default constructor
FileEntry::FileEntry(const QString& fileName)
: m_FileName(fileName)
, m_IsLoading(false)
, m_IsLoaded(false)
, m_Instance()
, m_Error()
, m_Camera()
, m_CameraIsSet(false)
, m_IconMode(GL_FILL)
{
	
}

// Copy constructor
FileEntry::FileEntry(const FileEntry& entry)
: m_FileName(entry.m_FileName)
, m_IsLoading(entry.m_IsLoading)
, m_IsLoaded(entry.m_IsLoaded)
, m_Instance(entry.m_Instance)
, m_Error(entry.m_Error)
, m_Camera(entry.m_Camera)
, m_CameraIsSet(entry.m_CameraIsSet)
{
	
}
// the destructor
FileEntry::~FileEntry()
{
	
}

//////////////////////////////////////////////////////////////////////
// Public Interface
//////////////////////////////////////////////////////////////////////

// Set the GLC_Instance of this file entry
void FileEntry::setInstance(GLC_Instance& instance)
{
	m_IsLoaded= true;
	m_Instance= instance;
}

// Get the GLC_Intsance of this file entry
GLC_Instance FileEntry::getInstance() const
{
	return m_Instance;
}

// return true if this file entry is loaded
bool FileEntry::isLoaded() const
{
	return m_IsLoaded;
}

// return true if this file entry is loading
bool FileEntry::isLoading() const
{
	return m_IsLoading;
}

// return true if this entry is ready to load
bool FileEntry::isReadyToLoad() const
{
	return (!m_IsLoading) && (!m_IsLoaded) && (!errorOccurWhileLoading());
}

// return true if an error occur while trying to load the file
bool FileEntry::errorOccurWhileLoading() const
{
	return !m_Error.isEmpty();
}

// return the loading error
QString FileEntry::getError() const
{
	return m_Error;
}

// Set the loading status of this entry
void FileEntry::setLoadingStatus(bool status)
{
	m_IsLoading= status;
}
// Get the number of Vertex of this entry
int FileEntry::getNumberOfVertex()
{
	GLC_Mesh2* pMesh= dynamic_cast<GLC_Mesh2*>(m_Instance.getGeometry());
	if (pMesh != NULL)
	{
		return pMesh->getNumberOfVertex();
	}
	else return 0;
}
// Get the number of Face of this entry
int FileEntry::getNumberOfFaces()
{
	GLC_Mesh2* pMesh= dynamic_cast<GLC_Mesh2*>(m_Instance.getGeometry());
	if (pMesh != NULL)
	{
		return pMesh->getNumberOfFaces();
	}
	else return 0;
	
}

