/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.0.2, packaged on February2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/

#ifndef FILEENTRY_H_
#define FILEENTRY_H_

#include <QString>
#include <glc_instance.h>
#include <glc_camera.h>


//////////////////////////////////////////////////////////////////////
//! \class FileEntry
/*! \brief FileEntry : The entry of File list*/
//////////////////////////////////////////////////////////////////////
class FileEntry
{
	
//////////////////////////////////////////////////////////////////////
/*! @name Constructor / Destructor */
//@{
//////////////////////////////////////////////////////////////////////	
public:
	//! Default constructor
	FileEntry(const QString& fileName= QString());
	//! Copy constructor
	FileEntry(const FileEntry&);
	//! the destructor
	virtual ~FileEntry();
//@}
//////////////////////////////////////////////////////////////////////
// Public Interface
//////////////////////////////////////////////////////////////////////
public:
	//! Get the File Name of this entry
	QString getFileName() const {return m_FileName;}
	//! Set the GLC_Instance of this file entry
	void setInstance(GLC_Instance&);
	//! Get the GLC_Intsance of this file entry
	GLC_Instance getInstance() const;
	//! return true if this file entry is loaded
	bool isLoaded() const;
	//! return true if this file entry is loading
	bool isLoading() const;
	//! return true if this entry is ready to load
	bool isReadyToLoad() const;
	//! return true if an error occur while trying to load the file
	bool errorOccurWhileLoading() const;
	//! set the loading error
	void setError(const QString& error) {m_Error= error;}
	//! return the loading error
	QString getError() const;
	//! Set the loading status of this entry
	void setLoadingStatus(bool);
	//! return true if the camera has been set
	bool cameraIsSet() const {return m_CameraIsSet;}
	//! Get the entry camera
	GLC_Camera getCamera() const {return m_Camera;}
	//! Set the entry Camera
	void setCamera(const GLC_Camera& cam)
	{
		m_CameraIsSet= true;
		m_Camera= cam;
	}
	//! Get the number of instance of this entry
	int getNumberOfInstance() const {return 1;}
	//! Get the number of Vertex of this entry
	int getNumberOfVertex();
	//! Get the number of Faces of this entry
	int getNumberOfFaces();
	//! get the entry polygon mode
	GLenum getPolygonMode() const {return m_Instance.getPolygonMode();}
	//! Set the entry Polygon mode
	void setPolygonMode(GLenum mode) {m_Instance.setPolygonMode(GL_FRONT_AND_BACK, mode);}
	//! Get the icon mode
	GLenum getIconMode() const {return m_IconMode;}
	//! Set the Icon model
	void setIconMode(GLenum mode) {m_IconMode= mode;}
	
	
//////////////////////////////////////////////////////////////////////
// private member
//////////////////////////////////////////////////////////////////////
private:
	//! The filename associate to this entry
	QString m_FileName;
	//! this entry is in loading process
	bool m_IsLoading;
	//! The instance as been set
	bool m_IsLoaded;
	//! The GLC_Instance of this file entry
	GLC_Instance m_Instance;
	//! Error description if error occur while loading
	QString m_Error;
	//! The camera off entry
	GLC_Camera m_Camera;
	//! true if the camer has been set
	bool m_CameraIsSet;
	//! the icon mode creation
	GLenum m_IconMode;
};

#endif /*FILEENTRY_H_*/
