/****************************************************************************

 This file is part of GLC-Player.
 Copyright (C) 2007-2008 Laurent Ribon (laumaya@users.sourceforge.net)
 Version 1.0.2, packaged on February2008.

 http://www.glc-player.net

 GLC-Player is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLC-Player is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLC-Player; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

*****************************************************************************/

#ifndef GLC_PLAYER_H
#define GLC_PLAYER_H

#include <QtGui/QMainWindow>
#include "ui_glc_player.h"
#include "OpenglView.h"
#include "OpenFileThread.h"
#include "FileEntry.h"


class glc_player : public QMainWindow
{
    Q_OBJECT

public:
    glc_player(QWidget *parent = 0);
    ~glc_player();
//////////////////////////////////////////////////////////////////////
// Virtual protected function
//////////////////////////////////////////////////////////////////////
protected:
	//! Close event handler
	void closeEvent(QCloseEvent*);
//////////////////////////////////////////////////////////////////////
// public Slots
//////////////////////////////////////////////////////////////////////
public slots:
	//! an instance as been selected
	void select(GLC_Instance*);
	//! an instance as been unselected
	void unselect();
	//! Info panel not supported
	void hideInfoPanel();
//////////////////////////////////////////////////////////////////////
// private Slots
//////////////////////////////////////////////////////////////////////
private slots:
	//! update the value of the progress bar
	void updateProgressBar(int);
	//! Menu File
	//! Open An existing file
	void open();
	//! Open a Recent File
	void openRecentFile();
	//! Menu Window
	//! Menu Edit
	//! View and edit mesh property
	void meshProperty();
	//! Menu View
	//! Reframe the view
	void reframe();
	//! Select mode
	void selectMode();
	//! define view center mode
	void viewCenterMode();
	//! Pan the view mode
	void panMode();
	//! Rotate the view mode
	void rotateMode();
	//! Zoom the view mode
	void zoomMode();
	//! Menu Tools
	//! Show application settings dialog
	void showSettings();
	//! A file as been Opened
	void fileOpened();
	//! load of File failed
	void loadFileFailed();
	//! Current file Item Changed
	void currentFileItemChanged(QListWidgetItem *, QListWidgetItem *);
	//! File Item as been clicked
	void fileItemClicked(QListWidgetItem *);
	//! Remove all file item from the current session
	void newSession();
	//! Remove unload item
	void removeUnloadFileItem();
	//! Remove item on error
	void removeItemOnError();	
	//! Start Loading
	void startLoadingButton();
	//! Stop Loading
	void stopLoadingButton();
	//! Take a snapshot
	void takeSnapShot();
	//! Delete the currentItem
	void deleteCurrentItem();
	//! Manage current item information displaying
	void manageItemInformationDisplay(int);
	//! Session Management visibility toggle
	void sessionManagementVisibilityToggle();
	//! The session management visibility change
	void sessionManagementVisibilityChanged(bool);
	//! Go to Point Rendering mode
	void pointsRenderingMode();
	//! Go to wireframe Rendering mode
	void wireframeRenderingMode();
	//! Go to shading Rendering Mode
	void shadingRenderingMode();
	//! Display about GLC_Player dialog box
	void aboutPlayer();
	//! Go to fullScreen Mode
	void fullScreen();
	//! Refresh the icon in item list
	void refreshIconInItemList();
	//! Display GLC_Player help page
	void help();
	
//////////////////////////////////////////////////////////////////////
// Private services Functions
//////////////////////////////////////////////////////////////////////
private:
	//! Create RecentFileActionArray
	void createRecentFileActionsArray();
	//! Update Recent Files
	void updateRecentsFiles();
	//! Open the file
	void openFile(const QString&);
	//! Set the current File
	void addToRecentFiles(const QString&);
	//! drag enter event
	void dragEnterEvent(QDragEnterEvent*);
	//! drop event
	void dropEvent(QDropEvent*);
	//! Load successful
	void loadSuccessful(QString);
	//! Add items
	/*! By default new item are gray*/
	void addItems(QStringList);
	//! Start Loading FileItem
	void startLoading();
	//! Set the current File Item
	void setCurrentFileItem(const QString&);
	//! Update the UI State
	void updateUIState();
	//! Compute the icon of a newly loaded file in back buffer
	void computeIconInBackBuffer(int);
	//! Return icon name with a size
	QString getIconName() const;
	//! Read Application Settings
	void readSettings();
	//! Write Application Settings
	void writeSettings();
//////////////////////////////////////////////////////////////////////
// private member
//////////////////////////////////////////////////////////////////////
private:
    Ui::glc_playerClass ui;
    OpenglView m_OpenglView;
    //! current file path
    QString m_CurrentPath;
    //! Loading progressBar
    QProgressBar *m_pProgressBar;
    //! Error Message dialog 
	QErrorMessage* m_pQErrorMessage;
	//! Recent File list
	QStringList m_RecentFilesList;
	//! Maximum number of recent file
	enum {MaxRecentFiles = 5};
	QAction* m_pRecentFileActionsArray[MaxRecentFiles];
	//! RecentFileSeparator
	QAction* m_pRecentFileSeparator;
	//! Current File name
	QString m_CurrentFileName;
	//! The thread wich open file
	OpenFileThread m_OpenFileThread;
	//! File Entry Hash table
	QHash<QString, FileEntry> m_FileEntryHash;
	//! A File Loading is in progress
	bool m_FileLoadingInProgress;
	//! A list Loading is in progress
	bool m_ListLoadingInProgress;
	//! continue List Loading
	bool m_ContinuListLoading;
	//! Number of file not loaded
	int m_NumberOfUnloadedFile;
	//! Number of File with error
	int m_NumberOfErrorFile;
	//! Size of the item list
	QSize m_iconSize;
	//! Make the first loading file current
	bool m_MakeFirstFileCurrent;
	//! Displaying thumbnail in list off files
	bool m_DisplayThumbnails;
	//! Create thumbnail while loading
	bool m_CreateThumbnailWhileLoading;
	//! Delete selected item
	QAction* m_pActionDeleteSelectedItem;
	//! Selected instance
	GLC_Instance* m_pCurrentSelection;
	//! display off the info panel
	bool m_dislayInfoPanel;
    
};

#endif // GLC_PLAYER_H
